@@ -9,12 +9,20 @@
         $('#txtDownMixAudioBoost', page).val(config.DownMixAudioBoost);
         page.querySelector('.txtEncoderPath').value = config.EncoderAppPath || '';
         $('#txtTranscodingTempPath', page).val(config.TranscodingTempPath || '');
+        $('#txtVaapiDevice', page).val(config.VaapiDevice || '');
+
+        page.querySelector('#selectH264Preset').value = config.H264Preset || '';
+        page.querySelector('#txtH264Crf').value = config.H264Crf || '';
 
         var selectEncoderPath = page.querySelector('#selectEncoderPath');
 
         selectEncoderPath.value = systemInfo.EncoderLocationType;
         onSelectEncoderPathChange.call(selectEncoderPath);
 
+        page.querySelector('#selectVideoDecoder').dispatchEvent(new CustomEvent('change', {
+            bubbles: true
+        }));
+
         Dashboard.hideLoadingMsg();
     }
 
@@ -64,6 +72,10 @@
                 config.TranscodingTempPath = $('#txtTranscodingTempPath', form).val();
                 config.EncodingThreadCount = $('#selectThreadCount', form).val();
                 config.HardwareAccelerationType = $('#selectVideoDecoder', form).val();
+                config.VaapiDevice = $('#txtVaapiDevice', form).val();
+
+                config.H264Preset = form.querySelector('#selectH264Preset').value;
+                config.H264Crf = parseInt(form.querySelector('#txtH264Crf').value || '0');
 
                 config.EnableThrottling = form.querySelector('#chkEnableThrottle').checked;
 
@@ -129,6 +141,19 @@
 
         var page = this;
 
+        page.querySelector('#selectVideoDecoder').addEventListener('change', function () {
+
+            if (this.value == 'vaapi') {
+
+                page.querySelector('.fldVaapiDevice').classList.remove('hide');
+                page.querySelector('#txtVaapiDevice').setAttribute('required', 'required');
+
+            } else {
+                page.querySelector('.fldVaapiDevice').classList.add('hide');
+                page.querySelector('#txtVaapiDevice').removeAttribute('required');
+            }
+        });
+
         $('#btnSelectEncoderPath', page).on("click.selectDirectory", function () {
 
             require(['directorybrowser'], function (directoryBrowser) {
