@@ -66,7 +66,7 @@
 
                     var premiereDate = datetime.parseISO8601Date(item.PremiereDate, true);
 
-                    if (premiereDate.getDate() == new Date().getDate() - 1) {
+                    if (datetime.isRelativeDay(premiereDate, -1)) {
                         dateText = Globalize.translate('Yesterday');
                     } else {
                         dateText = libraryBrowser.getFutureDateText(premiereDate, true);
